@@ -1,5 +1,5 @@
 
-::Version::setSubversionId {$Id: addressbook.tcl 11891 2010-01-11 20:18:34Z vivia $}
+::Version::setSubversionId {$Id: addressbook.tcl 12296 2011-02-15 13:52:33Z baaazen $}
 
 snit::type Addressbook {
 	variable contacts [list]
@@ -99,27 +99,27 @@ snit::type Addressbook {
 		}
 
 		if {$ab_done == 0 } {
-			::MSN::clearList FL
-			::MSN::clearList EL
-			foreach username [::abook::getAllContacts] {
-				::abook::removeContactFromList $username "FL"
-				::abook::removeContactFromList $username "EL"
-			}
-			::groups::Reset
-			::groups::Set 0 [trans nogroup]
+			#::MSN::clearList FL
+			#::MSN::clearList EL
+			#foreach username [::abook::getAllContacts] {
+			#	::abook::removeContactFromList $username "FL"
+			#	::abook::removeContactFromList $username "EL"
+			#}
+			#::groups::Reset
+			#::groups::Set 0 [trans nogroup]
 
 			after 0 [list $self ABFindAll [list $self ABFindAllDone $callback]]
 		}
 		if {$fm_done == 0 } {
-			::MSN::clearList BL
-			::MSN::clearList RL
-			::MSN::clearList AL
-			foreach username [::abook::getAllContacts] {
+			#::MSN::clearList BL
+			#::MSN::clearList RL
+			#::MSN::clearList AL
+			#foreach username [::abook::getAllContacts] {
 				#Remove user from all lists while receiving List data
-				::abook::removeContactFromList $username "AL"
-				::abook::removeContactFromList $username "BL"
-				::abook::removeContactFromList $username "RL"
-			}
+			#	::abook::removeContactFromList $username "AL"
+			#	::abook::removeContactFromList $username "BL"
+			#	::abook::removeContactFromList $username "RL"
+			#}
 			after 0 [list $self FindMembership [list $self FindMembershipDone $callback]]
 		}
 		if {$fm_done && $ab_done } {
@@ -128,31 +128,53 @@ snit::type Addressbook {
 	}
 
 	method FindMembershipDone { callback error } {
-		if {$error } {
+		if { $error == 0 } {
+			set fm_done 1
+			if { $ab_done == 1 } {
+				$self SynchronizeDone $callback $error
+			} elseif { $ab_done == -2 } {
+				$self SynchronizeDone $callback 2
+			} elseif { $ab_done == -1 } {
+				$self SynchronizeDone $callback 1
+			}
+		} elseif { $error == 1 } {
 			set fm_done -1
-			if {$ab_done != -1 } {
+			if { $ab_done == -2 } {
+				$self SynchronizeDone $callback 2
+			} elseif { $ab_done != 0 } {
 				$self SynchronizeDone $callback $error
 			}
-		} else {
-			set fm_done 1
-			if {$ab_done == 1 } {
+		} elseif { $error == 2 } {
+			set fm_done -2
+			if { $ab_done != 0 } {
 				$self SynchronizeDone $callback $error
 			}
 		}
 	}
 
 	method ABFindAllDone {callback error } {
-		if {$error } {
-			set ab_done -1
-			if {$fm_done != -1 } {
-				$self SynchronizeDone $callback $error
-			} 
-		} else {
-			set ab_done 1
-			if {$fm_done == 1 } {
-				$self SynchronizeDone $callback $error
-			}
-		}
+                if { $error == 0 } {
+                        set ab_done 1
+                        if { $fm_done == 1 } {
+                                $self SynchronizeDone $callback $error
+                        } elseif { $fm_done == -2 } {
+                                $self SynchronizeDone $callback 2
+                        } elseif { $fm_done == -1 } {
+                                $self SynchronizeDone $callback 1
+                        }
+                } elseif { $error == 1 } {
+                        set ab_done -1
+                        if { $fm_done == -2 } {
+                                $self SynchronizeDone $callback 2
+                        } elseif { $fm_done != 0 } {
+                                $self SynchronizeDone $callback $error
+                        }
+                } elseif { $error == 2 } {
+                        set ab_done -2
+                        if { $fm_done != 0 } {
+                                $self SynchronizeDone $callback $error
+                        }
+                }
 	}
 
 	method SynchronizeDone {callback error } {
@@ -185,6 +207,17 @@ snit::type Addressbook {
 		
 		if { [$soap GetStatus] == "success" } {
 			set xml  [$soap GetResponse]
+
+			::MSN::clearList BL
+			::MSN::clearList RL
+			::MSN::clearList AL
+			foreach username [::abook::getAllContacts] {
+				#Remove user from all lists while receiving List data
+				::abook::removeContactFromList $username "AL"
+				::abook::removeContactFromList $username "BL"
+				::abook::removeContactFromList $username "RL"
+			}
+
 			set i 0
 			while {1} {
 				set service [GetXmlNode $xml "soap:Envelope:soap:Body:FindMembershipResponse:FindMembershipResult:Services:Service" $i]
@@ -248,11 +281,21 @@ snit::type Addressbook {
 				}
 			} else {
 				$self _destroySoapReq $soap
+				foreach username [::abook::getAllContacts] {
+					foreach list [::abook::getContactData $username lists] {
+						::MSN::addToList $list $username
+					}
+				}
 				if {[catch {eval $callbk [list 1]} result]} {
 					bgerror $result
 				}
 			}
 		} else { 
+			foreach username [::abook::getAllContacts] {
+				foreach list [::abook::getContactData $username lists] {
+					::MSN::addToList $list $username
+				}
+			}
 			$self _destroySoapReq $soap
 			if {[catch {eval $callbk [list 1]} result]} {
 				bgerror $result
@@ -284,6 +327,15 @@ snit::type Addressbook {
 		if { [$soap GetStatus] == "success" } {
 			set xml  [$soap GetResponse]
 
+                        ::MSN::clearList FL
+                        ::MSN::clearList EL
+                        foreach username [::abook::getAllContacts] {
+                                ::abook::removeContactFromList $username "FL"
+                                ::abook::removeContactFromList $username "EL"
+                        }
+                        ::groups::Reset
+                        ::groups::Set 0 [trans nogroup]
+
 			set ownercid [GetXmlEntry $xml "soap:Envelope:soap:Body:ABFindAllResponse:ABFindAllResult:ab:abInfo:OwnerCID"]
 			if {$ownercid != "" } {
 				::abook::setPersonal cid $ownercid
